@@ -3,12 +3,12 @@ package Finance::CoinbasePro::API::CLI::Fill
 
 use strict;
 use warnings;
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 use Mouse;
 use Finance::CoinbasePro::API::CLI::Util::CurrencyUtil qw(format_currency);
 use Finance::CoinbasePro::API::CLI::Util::DateUtil
-  qw(getdatetime convert_seconds_to_human_time my_str2time);
+  qw(getdatetime convert_seconds_to_human_time my_str2time reformat_datetime);
 use Finance::CoinbasePro::API::CLI::Value;
 
 has 'created_at' => ( is => 'rw', isa => 'Str', required => 1 )
@@ -67,7 +67,7 @@ sub destination_currency {
     return $n[1];
 }
 
-# returns a string like '2018-06-13 11:14:11: buy BTC-USD: 10.00000000 BTC at $7,000.00, cost $70,000.00'
+# returns a string describing the fill
 sub to_str {
     my $self = shift;
     my ( $from_currency, $to_currency ) = split( /-/, $self->{product_id} );
@@ -76,40 +76,18 @@ sub to_str {
     my $str = sprintf(
         "%s: %s %s: %s at %s, offset %s",
 
-        #ago( $self->{created_at} ),
         reformat_datetime( $self->{created_at} ),
         $self->{side},    # buy/sell
         $self->{product_id},
         format_currency( $self->{size},  $from_currency ),
         format_currency( $self->{price}, $to_currency ),
         format_currency( $offset,        $to_currency )
+
     );
 
     return $str;
 }
 
-sub reformat_datetime {
-    my $s = shift;
-    print "$0: converting time $s\n";
-
-    my $t;    #= my_str2time( $s );
-    if ( !$t ) {
-        $t = my_str2time($s);
-
-        # my $dt = DateTime::Format::ISO8601->parse_datetime( $s );
-        # $t = $dt->datetime();
-    }
-
-    print " to epoch $t\n";
-    return getdatetime($t);
-}
-
-sub ago {
-    my $date = shift;
-    return convert_seconds_to_human_time( time() - my_str2time($date) )
-      . " ago";
-}
-
 1;
 __END__
 created_at => "2017-10-31T20:34:14.675Z",
@@ -119,8 +97,6 @@ order_id => "45eb4883-ed4f-4df5-bf0d-fde87dad2339",
 price => "0.04804000",
 product_id => "ETH-BTC",
 profile_id => "18f975e3-6d43-4127-aca5-7d2c13b2ea31",
-settled => 1,
-side => "sell",
 size => 30.77114653,
 trade_id => 1736807,
 usd_volume => undef,
@@ -128,25 +104,15 @@ user_id => "513378df5210ff660900002b",
 
 
 
-
-
-
-
-
-
-
-
-
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
-
 lib::::Finance::CoinbasePro::API::CLI::Fill - lib::::Finance::CoinbasePro::API::CLI::Fill
 
 
 =head1 DESCRIPTION
 
-returns a string like '2018-06-13 11:14:11: buy BTC-USD: 10.00000000 BTC at $7,000.00, cost $70,000.00'
+returns a string describing the fill
 
 
 =head1 REQUIRES
@@ -160,10 +126,6 @@ L<Mouse>
 
 =head1 METHODS
 
-=head2 ago
-
- ago();
-
 =head2 destination_currency
 
  destination_currency();
@@ -172,10 +134,6 @@ L<Mouse>
 
  destination_offset();
 
-=head2 reformat_datetime
-
- reformat_datetime();
-
 =head2 source_currency
 
  source_currency();
@@ -188,8 +146,7 @@ L<Mouse>
 
  to_str();
 
-returns a string like '2018-06-13 11:14:11: buy BTC-USD: 10.00000000 BTC at $7,000.00, cost $70,000.00'
-
+returns a string describing the fill
 
 
 =cut
